@@ -71,6 +71,9 @@ tree_cell * nasl_bn_cmp(lex_ctxt* lexic)
   /* key2 */
   s2 = get_str_local_var_by_name(lexic, "key2");
   sz2 = get_var_size_by_name(lexic, "key2");
+
+ if ( s1 == NULL || s2 == NULL )
+   goto fail;
   
   key1 = BN_new();
   key2 = BN_new();
@@ -158,6 +161,9 @@ tree_cell * nasl_pem_to(lex_ctxt* lexic, int type)
   /* priv bignum */
   priv = get_str_local_var_by_name(lexic, "priv");
   privlen = get_var_size_by_name(lexic, "priv");
+
+  if ( priv == NULL )
+	goto fail;
   
   /* priv bignum */
   passphrase = get_str_local_var_by_name(lexic, "passphrase");
@@ -248,6 +254,9 @@ tree_cell * nasl_dh_generate_key(lex_ctxt* lexic)
   s3 = get_str_local_var_by_name(lexic, "priv");
   sz3 = get_var_size_by_name(lexic, "priv");
 
+  if ( s1 == NULL || s2 == NULL || s3 == NULL )
+     goto fail;
+
   if ((dh = DH_new()) == NULL)
      goto fail;
  
@@ -329,6 +338,10 @@ tree_cell * nasl_dh_compute_key(lex_ctxt* lexic)
   s5 = get_str_local_var_by_name(lexic, "priv_key");
   sz5 = get_var_size_by_name(lexic, "priv_key");
 
+
+  if ( s1 == NULL || s2 == NULL || s3 == NULL || s4 == NULL || s5 == NULL )
+     goto fail;
+
   if ((dh = DH_new()) == NULL)
      goto fail;
  
@@ -396,6 +409,9 @@ tree_cell * nasl_rsa_public_decrypt(lex_ctxt* lexic)
   s3 = get_str_local_var_by_name(lexic, "n");
   sz3 = get_var_size_by_name(lexic, "n");
 
+  if ( s1 == NULL || s2 == NULL || s3 == NULL ) 
+    goto fail;
+
   if ((rsa = RSA_new()) == NULL)
     goto fail;
  
@@ -458,6 +474,9 @@ tree_cell * nasl_rsa_sign(lex_ctxt* lexic)
   s4 = get_str_local_var_by_name(lexic, "d");
   sz4 = get_var_size_by_name(lexic, "d");
 
+  if ( s1 == NULL || s2 == NULL || s3 == NULL || s4 == NULL )
+    goto fail;
+
   if ((rsa = RSA_new()) == NULL)
     goto fail;
  
@@ -522,6 +541,9 @@ tree_cell * nasl_bf_cbc(lex_ctxt* lexic, int enc)
   data = get_str_local_var_by_name(lexic, "data");
   datalen = get_var_size_by_name(lexic, "data");
 
+  if ( enckey == NULL || data == NULL || iv == NULL )
+	goto fail;
+
   /* key len = 16 : { "blowfish-cbc", 	SSH_CIPHER_SSH2, 8, 16, EVP_bf_cbc }*/
   BF_set_key(&key, 16, enckey);
 
@@ -599,6 +621,8 @@ tree_cell * nasl_dsa_do_verify(lex_ctxt* lexic)
   /* data */
   data = get_str_local_var_by_name(lexic, "data");
   datalen = get_var_size_by_name(lexic, "data");
+  if  ( p == NULL || g == NULL || q == NULL || pub == NULL || r == NULL || s == NULL )
+	goto fail;
 
   if ((dsa = DSA_new()) == NULL)
     goto fail;
@@ -671,6 +695,9 @@ tree_cell * nasl_dsa_do_sign(lex_ctxt* lexic)
   data = get_str_local_var_by_name(lexic, "data");
   datalen = get_var_size_by_name(lexic, "data");
 
+  if ( p == NULL || g == NULL || q == NULL || pub == NULL || priv == NULL || data == NULL )
+	goto fail;
+
   if ((dsa = DSA_new()) == NULL)
     goto fail;
   
