@@ -828,3 +828,49 @@ nasl_mktime(lex_ctxt* lexic)
   retc->x.i_val = tictac;
   return retc;
 }
+
+
+tree_cell*
+nasl_open_sock_kdc(lex_ctxt* lexic)
+{
+  tree_cell		*retc;
+  struct timeval	t;
+  int                   timeout = 30;
+  int                   port = 88;
+  char                  *hostname = NULL; /* Domain name for windows */
+  int                   tcp = 0;
+  int                   ret;
+  struct arglist        *script_infos, *prefs;
+  char                  *_port = NULL, *_tcp = NULL;
+  char * val;
+  int type;
+
+
+
+  script_infos = lexic->script_infos;
+
+  hostname = plug_get_key(script_infos, "Secret/kdc_hostname", &type);
+  if ( ! hostname || type != KB_TYPE_STR )
+	return NULL;
+  
+  port = (int)plug_get_key(script_infos, "Secret/kdc_port", &type);
+  if ( port <= 0 || type != KB_TYPE_INT )
+	return NULL;
+
+
+  tcp = (int)plug_get_key(script_infos, "Secret/kdc_use_tcp", &type);
+  if ( tcp < 0 || type != KB_TYPE_INT )
+	tcp = 0;
+
+  if (tcp == 0)
+    ret = open_sock_opt_hn(hostname, port, SOCK_DGRAM, IPPROTO_UDP, timeout);
+  else
+    ret = open_sock_opt_hn(hostname, port, SOCK_STREAM, IPPROTO_TCP, timeout);
+
+  if (ret < 0)
+    return NULL;
+
+  retc = alloc_typed_cell(CONST_INT);
+  retc->x.i_val = ret;
+  return retc;
+}
